@@ -31,7 +31,11 @@
 #include "debug.h"
 
 #undef VTE_DISABLE_DEPRECATED
-#include "vte.h"
+#include <vte/vte.h>
+
+#ifdef WITH_PCRE2
+#include "vtepcre2.h"
+#endif
 
 #include <glib/gi18n.h>
 
@@ -44,6 +48,10 @@ static const char *builtin_dingus[] = {
   NULL
 };
 
+#ifdef WITH_PCRE2
+static gboolean use_gregex = FALSE;
+#endif
+
 static void
 window_title_changed(GtkWidget *widget, gpointer win)
 {
@@ -141,7 +149,8 @@ button_pressed(GtkWidget *widget, GdkEventButton *event, gpointer data)
 	char *match;
 	int tag;
 	GtkBorder padding;
-	int char_width, char_height;
+        gboolean has_extra_match;
+        char *extra_match;
 
 	switch (event->button) {
 	case 3:
@@ -150,12 +159,9 @@ button_pressed(GtkWidget *widget, GdkEventButton *event, gpointer data)
                 gtk_style_context_get_padding(gtk_widget_get_style_context(widget),
                                               gtk_widget_get_state_flags(widget),
                                               &padding);
-                char_width = vte_terminal_get_char_width (terminal);
-		char_height = vte_terminal_get_char_height (terminal);
-		match = vte_terminal_match_check(terminal,
-						 (event->x - padding.left) / char_width,
-						 (event->y - padding.top) / char_height,
-						 &tag);
+		match = vte_terminal_match_check_event(terminal,
+                                                       (GdkEvent*)event,
+                                                       &tag);
 		if (match != NULL) {
 			g_print("Matched `%s' (%d).\n", match, tag);
 			g_free(match);
@@ -163,6 +169,32 @@ button_pressed(GtkWidget *widget, GdkEventButton *event, gpointer data)
 				vte_terminal_match_remove(terminal, tag);
 			}
 		}
+#ifdef WITH_PCRE2
+                if (!use_gregex) {
+                        VteRegex *regex = vte_regex_new("\\d+", -1, PCRE2_UTF, NULL);
+                        has_extra_match = vte_terminal_event_check_regex_simple(terminal,
+                                                                                (GdkEvent*)event,
+                                                                                &regex, 1,
+                                                                                0,
+                                                                                &extra_match);
+                        vte_regex_unref(regex);
+                } else
+#endif
+                {
+                        GRegex *regex = g_regex_new("\\d+", 0, 0, NULL);
+                        has_extra_match = vte_terminal_event_check_gregex_simple(terminal,
+                                                                                 (GdkEvent*)event,
+                                                                                 &regex, 1,
+                                                                                 0,
+                                                                                 &extra_match);
+                        g_regex_unref(regex);
+                }
+
+                if (has_extra_match)
+                        g_print("Extra regex match: %s\n", extra_match);
+                else
+                        g_print("Extra regex didn't match\n");
+                g_free(extra_match);
 		break;
 	case 1:
 	case 2:
@@ -528,21 +560,43 @@ add_dingus (VteTerminal *terminal,
             char **dingus)
 {
         const GdkCursorType cursors[] = { GDK_GUMBY, GDK_HAND1 };
-        GRegex *regex;
-        GError *error;
         int id, i;
 
         for (i = 0; dingus[i]; ++i) {
-                error = NULL;
-                if (!(regex = g_regex_new(dingus[i], G_REGEX_OPTIMIZE, 0, &error))) {
+                GRegex *gregex = NULL;
+                GError *error = NULL;
+#ifdef WITH_PCRE2
+                VteRegex *regex = NULL;
+
+                if (!use_gregex)
+                        regex = vte_regex_new(dingus[i], -1,
+                                              PCRE2_UTF | PCRE2_NO_UTF_CHECK,
+                                              &error);
+                else
+#endif
+                        gregex = g_regex_new(dingus[i], G_REGEX_OPTIMIZE, 0, &error);
+
+                if (error) {
                         g_warning("Failed to compile regex '%s': %s\n",
                                   dingus[i], error->message);
                         g_error_free(error);
                         continue;
                 }
 
-                id = vte_terminal_match_add_gregex(terminal, regex, 0);
-                g_regex_unref (regex);
+#ifdef WITH_PCRE2
+                if (!use_gregex)
+                        id = vte_terminal_match_add_regex(terminal, regex, 0);
+                else
+#endif
+                        id = vte_terminal_match_add_gregex(terminal, gregex, 0);
+
+#ifdef WITH_PCRE2
+                if (regex)
+                        vte_regex_unref(regex);
+#endif
+                if (gregex)
+                        g_regex_unref (gregex);
+
                 vte_terminal_match_set_cursor_type(terminal, id,
                                                    cursors[i % G_N_ELEMENTS(cursors)]);
         }
@@ -563,13 +617,13 @@ main(int argc, char **argv)
         char *transparent = NULL;
         char *encoding = NULL;
         char *cjk_ambiguous_width = NULL;
-	gboolean audible = TRUE,
+	gboolean audible = FALSE,
 		 debug = FALSE, no_builtin_dingus = FALSE, dbuffer = TRUE,
 		 console = FALSE, keep = FALSE,
                 icon_title = FALSE, shell = TRUE,
 		 reverse = FALSE, use_geometry_hints = TRUE,
-		 use_scrolled_window = FALSE,
-		 show_object_notifications = FALSE, rewrap = TRUE;
+                use_scrolled_window = FALSE,
+                show_object_notifications = FALSE, rewrap = TRUE;
 	char *geometry = NULL;
 	gint lines = -1;
 	const char *message = "Launching interactive shell...\r\n";
@@ -603,6 +657,13 @@ main(int argc, char **argv)
 			G_OPTION_ARG_STRING_ARRAY, &dingus,
 			"Add regex highlight", NULL
 		},
+#ifdef WITH_PCRE2
+		{
+			"gregex", 0, 0,
+			G_OPTION_ARG_NONE, &use_gregex,
+			"Use GRegex instead of PCRE2", NULL
+		},
+#endif
 		{
 			"no-rewrap", 'R', G_OPTION_FLAG_REVERSE,
 			G_OPTION_ARG_NONE, &rewrap,
@@ -624,9 +685,9 @@ main(int argc, char **argv)
 			"Disable double-buffering", NULL
 		},
 		{
-			"audible", 'a', G_OPTION_FLAG_REVERSE,
+			"audible-bell", 'a', 0,
 			G_OPTION_ARG_NONE, &audible,
-			"Use visible, instead of audible, terminal bell",
+			"Use audible terminal bell",
 			NULL
 		},
 		{
@@ -760,16 +821,14 @@ main(int argc, char **argv)
 
         _vte_debug_init();
 
-	/* Have to do this early. */
-	if (getenv("VTE_PROFILE_MEMORY")) {
-		if (atol(getenv("VTE_PROFILE_MEMORY")) != 0) {
-			g_mem_set_vtable(glib_mem_profiler_table);
-		}
-	}
         if (g_getenv("VTE_CJK_WIDTH")) {
                 g_printerr("VTE_CJK_WIDTH is not supported anymore, use --cjk-width instead\n");
         }
 
+        /* Not interested in silly debug spew, bug #749195 */
+        if (g_getenv ("G_ENABLE_DIAGNOSTIC") == NULL)
+                g_setenv ("G_ENABLE_DIAGNOSTIC", "0", TRUE);
+
 	context = g_option_context_new (" - test VTE terminal emulation");
 	g_option_context_add_main_entries (context, options, NULL);
 	g_option_context_add_group (context, gtk_get_option_group (TRUE));
@@ -910,7 +969,6 @@ main(int argc, char **argv)
 
 	/* Set some defaults. */
 	vte_terminal_set_audible_bell(terminal, audible);
-	vte_terminal_set_visible_bell(terminal, !audible);
 	vte_terminal_set_cursor_blink_mode(terminal, cursor_blink_mode);
 	vte_terminal_set_scroll_on_output(terminal, FALSE);
 	vte_terminal_set_scroll_on_keystroke(terminal, TRUE);
