@@ -21,14 +21,10 @@
 #ifndef vte_vtedraw_h_included
 #define vte_vtedraw_h_included
 
-
 #include <glib.h>
 #include <gtk/gtk.h>
 #include <cairo.h>
-#include "vtebg.h"
-#include "vte.h"
 #include "vteunistr.h"
-#include "vte-gtk-compat.h"
 
 G_BEGIN_DECLS
 
@@ -68,37 +64,23 @@ struct _vte_draw_text_request {
 guint _vte_draw_get_style(gboolean bold, gboolean italic);
 
 /* Create and destroy a draw structure. */
-struct _vte_draw *_vte_draw_new(GtkWidget *widget);
+struct _vte_draw *_vte_draw_new(void);
 void _vte_draw_free(struct _vte_draw *draw);
 
 cairo_t *_vte_draw_get_context (struct _vte_draw *draw);
 
-/* Begin and end a drawing operation.  If anything is buffered locally, it is
-   flushed to the window system when _end() is called. */
-void _vte_draw_start(struct _vte_draw *draw);
-void _vte_draw_end(struct _vte_draw *draw);
+void _vte_draw_set_cairo(struct _vte_draw *draw,
+                         cairo_t *cr);
 
 void _vte_draw_set_background_solid(struct _vte_draw *draw,
-				    double red,
-				    double green,
-				    double blue,
-				    double opacity);
-void _vte_draw_set_background_image(struct _vte_draw *draw,
-				    VteBgSourceType type,
-				    GdkPixbuf *pixbuf,
-				    const char *file,
-				    const PangoColor *color,
-				    double saturation);
-void _vte_draw_set_background_scroll(struct _vte_draw *draw,
-				     gint x, gint y);
+                                    const GdkRGBA *color);
 
-void _vte_draw_clip(struct _vte_draw *draw, GdkRegion *region);
 void _vte_draw_clear(struct _vte_draw *draw,
 		     gint x, gint y, gint width, gint height);
 
 void _vte_draw_set_text_font(struct _vte_draw *draw,
-			     const PangoFontDescription *fontdesc,
-			     VteTerminalAntiAlias anti_alias);
+                             GtkWidget *widget,
+			     const PangoFontDescription *fontdesc);
 void _vte_draw_get_text_metrics(struct _vte_draw *draw,
 				gint *width, gint *height, gint *ascent);
 int _vte_draw_get_char_width(struct _vte_draw *draw, vteunistr c, int columns,
@@ -119,9 +101,6 @@ void _vte_draw_fill_rectangle(struct _vte_draw *draw,
 void _vte_draw_draw_rectangle(struct _vte_draw *draw,
 			      gint x, gint y, gint width, gint height,
 			      const PangoColor *color, guchar alpha);
-void _vte_draw_set_source_color_alpha (struct _vte_draw *draw,
-                                       const PangoColor *color,
-                                       guchar            alpha);
 
 G_END_DECLS
 
